@@ -3,7 +3,8 @@ package Dash::Dependencies::DashDependency;
 use Moo;
 use strictures 2;
 use namespace::clean;
-use overload '""' => "_stringify";
+use overload
+  '""' => "_stringify";
 
 has component_id => ( is => 'ro' );
 
@@ -28,7 +29,7 @@ Dash::Dependencies::DashDependency
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHOR
 
@@ -36,7 +37,7 @@ Pablo Rodríguez González <pablo.rodriguez.gonzalez@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Pablo Rodríguez González.
+This software is Copyright (c) 2022 by Pablo Rodríguez González.
 
 This is free software, licensed under:
 
